# Iteru


[![image](https://img.shields.io/pypi/v/iteru.svg)](https://pypi.python.org/pypi/iteru)


**A Google Earth Engine-Based Interactive Web Application for Continuously Monitoring the GERD Reservoir in Ethiopia**


-   Free software: MIT license
    

## Features


-   Display Earth Engine data layers for interactive mapping.
-   Create Sentinel-1 timelaspe animations of the [GERD](https://en.wikipedia.org/wiki/Grand_Ethiopian_Renaissance_Dam) reservoir waterbody.
-   Map the [GERD](https://en.wikipedia.org/wiki/Grand_Ethiopian_Renaissance_Dam) reservoir surface water extent.
-   Calculate the [GERD](https://en.wikipedia.org/wiki/Grand_Ethiopian_Renaissance_Dam) reservoir surface water level. 
-   Compute the [GERD](https://en.wikipedia.org/wiki/Grand_Ethiopian_Renaissance_Dam) reservoir waterbody volume.

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
